==> apache-wicket-9.10.0.tar.gz: apache-wicket-9.10.0/wicket-spring/src/test/java/org/apache/wicket/spring/FieldBeansCollectorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.spring;

import org.apache.wicket.spring.FieldBeansCollector.FieldType;
import org.junit.jupiter.api.Test;
import org.springframework.core.ResolvableType;

import java.lang.reflect.Field;
import java.util.List;

import static org.junit.jupiter.api.Assertions.assertTrue;


public class FieldBeansCollectorTest
{
	public List<List<String>> listOfStringList;

	public List genericList;

	@Test
	public void resolveGenericList() throws Exception
	{
		Field field = getClass().getField("listOfStringList");
		ResolvableType resolvableType = ResolvableType.forField(field);

		FieldBeansCollector fieldBeansCollector = new FieldBeansCollector(resolvableType);

		assertTrue(fieldBeansCollector.getFieldType() == FieldType.LIST);
	}

	@Test
	public void resolveRowList() throws Exception
	{
		Field field = getClass().getField("genericList");

		ResolvableType resolvableType = ResolvableType.forField(field);
		FieldBeansCollector fieldBeansCollector = new FieldBeansCollector(resolvableType);

		assertTrue(fieldBeansCollector.getFieldType() == FieldType.LIST);
	}
}

==> apache-wicket-10.3.0.tar.gz: apache-wicket-10.3.0/wicket-spring/src/test/java/org/apache/wicket/spring/FieldBeansCollectorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.spring;

import org.apache.wicket.spring.FieldBeansCollector.FieldType;
import org.junit.jupiter.api.Test;
import org.springframework.core.ResolvableType;

import java.lang.reflect.Field;
import java.util.List;

import static org.junit.jupiter.api.Assertions.assertEquals;


public class FieldBeansCollectorTest
{
	public List<List<String>> listOfStringList;

	public List genericList;

	@Test
	public void resolveGenericList() throws Exception
	{
		Field field = getClass().getField("listOfStringList");
		ResolvableType resolvableType = ResolvableType.forField(field);

		FieldBeansCollector fieldBeansCollector = new FieldBeansCollector(resolvableType);

		assertEquals(FieldType.LIST, fieldBeansCollector.getFieldType());
	}

	@Test
	public void resolveRowList() throws Exception
	{
		Field field = getClass().getField("genericList");

		ResolvableType resolvableType = ResolvableType.forField(field);
		FieldBeansCollector fieldBeansCollector = new FieldBeansCollector(resolvableType);

		assertEquals(FieldType.LIST, fieldBeansCollector.getFieldType());
	}
}
